: NMDAR.mod   NMDA receptor channel
NEURON {
    POINT_PROCESS nmdanet
    RANGE R, g, mg
    NONSPECIFIC_CURRENT i
    GLOBAL Cdur, Alpha, Beta, Erev, Rinf, Rtau
}
UNITS {
    (nA) = (nanoamp)
    (mV) = (millivolt)
    (umho) = (micromho)
    (mM) = (milli/liter)
}
PARAMETER {
    Cdur   = 1  (ms)     : transmitter duration (rising phase)
    Alpha  = 0.35 (/ms)  : forward (binding) rate
    Beta   = 0.035 (/ms) : backward (unbinding) rate
    Erev   = 0 (mV)      : reversal potential
    mg     = 1 (mM)      : external magnesium concentration
}
ASSIGNED {
    v      (mV)          : postsynaptic voltage
    i 	   (nA)	         : current = g*(v - Erev)
    g 	   (umho)        : conductance
    Rinf                 : steady state channels open
    Rtau   (ms)          : time constant of channel binding
    synon
}
STATE {Ron Roff}
INITIAL {
    Rinf = Alpha / (Alpha + Beta)
    Rtau = 1 / (Alpha + Beta)
    synon = 0
}

BREAKPOINT {
    SOLVE release METHOD cnexp
    g = mgblock(v)*(Ron + Roff)*1(umho)
    i = g*(v - Erev)		
}

DERIVATIVE release {
    Ron' = (synon*Rinf - Ron)/Rtau
    Roff' = -Beta*Roff
}
FUNCTION mgblock(v(mV)) {
    TABLE 
    DEPEND mg
    FROM -140 TO 80 WITH 1000
    mgblock = 1 / (1 + exp(0.062 (/mV) * -v) * (mg / 3.57 (mM)))
}
NET_RECEIVE(weight, on, nspike, r0, t0 (ms)) {
    if (flag == 0) { : a spike, so turn on if not already in a Cdur pulse
        nspike = nspike + 1
        if (!on) {
            r0 = r0*exp(-Beta*(t - t0))
            t0 = t
            on = 1
            synon = synon + weight
            Ron =  Ron + r0
            Roff = Roff - r0
        }
        net_send(Cdur, nspike)
    }
    if (flag == nspike) { : if this associated with last spike then turn off
        r0 = weight*Rinf + (r0 - weight*Rinf)*exp(-(t - t0)/Rtau)
        t0 = t
        synon = synon - weight
        Ron = Ron - r0
        Roff = Roff + r0
        on = 0
    }
}
