# n02.py:  a simple hh cell, with depolarized equilibrium potential
#          for leak current                  
from neuron import h
import neuron
import numpy as np
import matplotlib.pyplot as plt

tstop = 200.0
v_init = -65.0

soma = h.Section()
soma.diam = 30.0
soma.L = 30.0
soma.insert('hh')
soma.el_hh = -30.0  # <== changed

cvode = h.CVode()
cvode.active(1)
cvode.atol(1.0e-5)

vv = h.Vector()             # membrane potential vector
tv = h.Vector()             # time stamp vector
vv.record(soma(0.5)._ref_v)
tv.record(h._ref_t)

h.finitialize(v_init)
h.fcurrent()
neuron.run(tstop)

ax = plt.subplot()
ax.set_ylim([-80,40])
ax.plot(tv.as_numpy(), vv.as_numpy())
plt.xlabel('Time (ms)')
plt.ylabel('Potential (mV)')
plt.savefig('../figs/n02.pdf')
plt.show()
