# n05.py

from neuron import h
import neuron
import numpy as np
import matplotlib.pyplot as plt

tstop = 25
v_init = -65.0

soma = h.Section()
soma.L = 30.0
soma.diam = 30.0
soma.nseg = 1
soma.insert('hh')

ap_dend = h.Section()
ap_dend.L = 500.0
ap_dend.diam = 2.0
ap_dend.nseg = 23

ap_dend.insert('hh')
ap_dend.gnabar_hh = 0.012
ap_dend.gkbar_hh = 0.0036
ap_dend.gl_hh = 0.00003

ap_dend.connect(soma, 1.0, 0)

# synaptic input
esyn = h.AlphaSynapse(0.5, sec = ap_dend)
esyn.onset = 5
esyn.tau = 0.1
esyn.gmax = 0.05
esyn.e = 0.0

cvode = h.CVode()
cvode.active(1)
cvode.atol(1.0e-5)

tv = h.Vector()
vs = h.Vector()
va1 = h.Vector()
va2 = h.Vector()

tv.record(h._ref_t)
vs.record(soma(0.5)._ref_v)
va1.record(ap_dend(0.1)._ref_v)
va2.record(ap_dend(0.9)._ref_v)

h.finitialize(v_init)
h.fcurrent()
neuron.run(tstop)

ax = plt.subplot()
ax.plot(tv.as_numpy(), vs.as_numpy())
ax.plot(tv.as_numpy(), va1.as_numpy())
ax.plot(tv.as_numpy(), va2.as_numpy())
plt.xlabel('Time (ms)')
plt.ylabel('Potential (mV)')
plt.savefig('../figs/n05.pdf')
plt.show()
