# n07.py

from neuron import h
import neuron
import numpy as np
import matplotlib.pyplot as plt

tstop = 40.0
h.dt = 0.01
v_init = -65

soma = h.Section()
soma.L = 30.0
soma.diam = 30.0
soma.nseg = 1
soma.insert('hh')

ap_dend = h.Section()
ap_dend.L = 500.0
ap_dend.diam = 2.0
ap_dend.nseg = 23
ap_dend.insert('hh')
ap_dend.gnabar_hh = 0.012
ap_dend.gkbar_hh = 0.0036
ap_dend.gl_hh = 0.00003

ap_dend.connect(soma, 1.0, 0)

esyn = h.AlphaSynapse(0.1, sec = ap_dend)
esyn.onset = 10
esyn.tau   = 0.1
esyn.gmax  = 0.04
esyn.e     = 0.0

isyn = [h.AlphaSynapse(0.1*i+0.05, sec = ap_dend) for i in range(10)]
for i in range(10):
    isyn[i].onset = 5
    isyn[i].tau = 3.0
    isyn[i].e = -70 #v_init

cvode = h.CVode()
cvode.active(1)
cvode.atol(1.0e-5)

tv = h.Vector()
vs = h.Vector()
tv.record(h._ref_t)
vs.record(soma(0.5)._ref_v)

tr = []
tt = []

# synaptic input
for j in range(-1,10):    # -1 for excitatory input only
    for i in range(10):
        if i == j:
            isyn[i].gmax = 0.02
        else:
            isyn[i].gmax = 0
    
    h.finitialize(v_init)
    h.fcurrent()
    while h.t < tstop:
        cvode.fixed_step()

    tt.append(np.copy(tv.as_numpy()))
    tr.append(np.copy(vs.as_numpy()))

ax = plt.subplot()
ax.set_xlim([5.0, 20])
ax.set_ylim([-80,40])
#ax.set_xlim([8,14])
#ax.set_ylim([-70,-50])
for j  in range(11):
    ax.plot(tt[j], tr[j])
plt.xlabel('Time (ms)')
plt.ylabel('Potential (mV)')
plt.savefig('../figs/n07.pdf')
#plt.savefig('../figs/n07b.pdf')
plt.show()
