# n08.py: connecting neurons

from neuron import h
import neuron
import numpy as np
import matplotlib.pyplot as plt

class HHneuron():  # class definition
    def __init__(self):
        self.soma = h.Section()
        self.ap_dend = h.Section()

        self.soma.L = 30
        self.soma.diam = 30
        self.soma.nseg = 1
        self.soma.insert('hh')

        self.ap_dend.L = 500
        self.ap_dend.diam = 2
        self.ap_dend.nseg = 23
        self.ap_dend.insert('hh')
        self.ap_dend.gnabar_hh = 0.012
        self.ap_dend.gkbar_hh  = 0.0036
        self.ap_dend.gl_hh = 0.00003

        self.ap_dend.connect(self.soma, 1, 0)
        self.esyn = h.Exp2Syn(0.5, sec=self.ap_dend)
        self.esyn.tau1 = 0.5
        self.esyn.tau2 = 1.0
        self.esyn.e = 0

tstop = 100.0
v_init = -65.0

# 2 cells
hh_neuron = [HHneuron() for i in range(2)]

# synapse
stim = h.NetStim(0.5)
stim.interval = 20
stim.number = 3
stim.start = 20
stim.noise = 0

# connections
nclist = []
nclist.append(h.NetCon(stim, hh_neuron[0].esyn, 0.0, 0, 0.02))
nclist.append(h.NetCon(hh_neuron[0].soma(0.5)._ref_v, hh_neuron[1].esyn, 10, 1, 0.02))

cvode = h.CVode()
cvode.active(1)
cvode.atol(1.0e-5)

tv = h.Vector()
vs0 = h.Vector()
vs1 = h.Vector()

tv.record(h._ref_t)
vs0.record(hh_neuron[0].soma(0.5)._ref_v)
vs1.record(hh_neuron[1].soma(0.5)._ref_v)

h.finitialize(v_init)
h.fcurrent()
neuron.run(tstop)

ax = plt.subplot()
ax.plot(tv.as_numpy(), vs0.as_numpy())
ax.plot(tv.as_numpy(), vs1.as_numpy())
plt.xlabel('Time (ms)')
plt.ylabel('Potential (mV)')
plt.savefig('../figs/n08.pdf')
plt.show()
