#  n12.py

import math
import numpy as np
import neuron
from neuron import h
import matplotlib.pyplot as plt

h.load_file("nrngui.hoc")
h.load_file("stdlib.hoc")
h.load_file("../models/tc200.geo")

nSyn  = 30
tstop = 100.0
dt    = 0.01
v_init= -65.0

# Properties of dendrites
dendritic = []
for sec in h.allsec():
    sec.insert('hh')
    sec.Ra = 100
    if sec.name() !=  'soma':
        dendritic.append(sec)
print('number of dend =', len(dendritic))

for sec in dendritic:
    d = 1.0e5 * math.sqrt(sec.diam/(4.0*h.PI*100.0*sec.Ra*sec.cm))
    sec.nseg = int((int((sec.L/(0.1*d))+0.9)/2)*2+1)
    
# total dendritic length
totalLength = 0.0
for sec in dendritic:
    totalLength += sec.L
print('Tolal dendrite length = ', totalLength)

# Shape Plot
sh = h.Shape(1)
sh.size(-150, 150, -150, 150)
# stimulation
stim = h.NetStim(0.5)
stim.interval = 50.0
stim.number = 2
stim.start = 20.0
stim.noise = 0

nclist = []
locvec = np.random.uniform(0.0, totalLength, nSyn)
esyn = []
nclist = []
for k in range(nSyn):
    l=0
    l1 = 0
    found = 0
    for sec in dendritic:
        if found==0:
            l1 += sec.L
            if locvec[k] < l1:
                lx = (locvec[k]-l)/sec.L
                e = h.Exp2Syn(lx, sec=sec)
                esyn.append(e)
                sh.color(2, sec=sec)
                sh.point_mark(esyn[k],3,'O',2)
                nclist.append( h.NetCon(stim, esyn[k], 0.0, 0, 0.001))
                found = 1
                break
            l = l1
sh.flush()
h.doEvents()
sh.printfile('../figs/n12shape.eps')

# main loop
cvode = h.CVode()
cvode.active(1)
cvode.atol(1.0e-5)

tv = h.Vector()
vs = h.Vector()
tv.record(h._ref_t)
vs.record(h.soma(0.5)._ref_v)

h.finitialize(v_init)
h.fcurrent()
neuron.run(tstop)

ax = plt.subplot()
#ax.set_ylim([-70.0, -35.0])
ax.plot(tv.as_numpy(), vs.as_numpy())
plt.savefig('../figs/n12.pdf')    
plt.show()
