#  n13.py
import numpy as np
import neuron
from neuron import h
import matplotlib.pyplot as plt

h.load_file('nrngui.hoc')
h.load_file("stdlib.hoc")
h.load_file('../models/tc200.geo')

tstop = 200.0
dt = 0.01
v_init = -65.0

nSyn=100      # number of synapses
mdel = 10.0   # mean of synaptic delay
sdel = 1.0    # sd of synaptic delay
w = 0.001     # synaptic weight
br = 5

def measureDist(sec):
    dx = 0.0
    sec1 = sec
    while True:
        sr = h.SectionRef(sec=sec1)
        if sr.has_parent() < 1.0:
            break
        dx += sec1.L
        sec1 = h.SectionRef(sec=sec1).parent
    return dx

def countBranch(sec):
    bx = 0
    sec1 = sec
    while True:
        sr = h.SectionRef(sec=sec1)
        if sr.has_parent() < 1.0:
            break
        bx += 1
        print(sec1.name())
        sec1 = h.SectionRef(sec=sec1).parent
    return bx

#-------------------------------
# Properties of dendrites

dendritic = []
for sec in h.allsec():
    sec.insert('hh')
    sec.Ra = 100.0
    if sec.name() != 'soma':
        dendritic.append(sec)

for sec in dendritic:
    d = h.lambda_f(100,sec=sec)
    sec.nseg = int(int((sec.L/(0.1*d))+0.9)/2*2+1)

dendriticN = []
total_length=0
for sec in dendritic:
    if countBranch(sec) >= br:
        dendriticN.append(sec)
        total_length += sec.L

print('total length of ">=', br, 'th-branch" dendrites = ', total_length)

# Shape Plot
sh = h.Shape(1)

# stimulation
stim = h.NetStim(0.5)
stim.interval = 50.0
stim.number = 2
stim.start = 50.0
stim.noise = 0

# random generator	
locvec = np.random.uniform(0, total_length, nSyn)
delvec = np.random.normal(mdel, sdel, nSyn)
nc = []
esyn = []
for k in range(nSyn-1):
    l = 0
    l1 = 0
    found = 0
    for sec in dendriticN:
        if found == 0:
            l1 += sec.L
            if l1 > locvec[k]:
                lx = (locvec[k]-l)/sec.L
                e = h.Exp2Syn(lx, sec=sec)
                esyn.append(e)
                sh.color(2, sec=sec)
                sh.point_mark(esyn[k],3,'O',2)
                nc.append(h.NetCon(stim, esyn[k], 0.0, delvec[k], w))
                found = 1
                break                
            l = l1
sh.flush()
h.doEvents()
sh.printfile('../figs/n13shape.eps')
# main loop

cvode = h.CVode()
cvode.active(1)
cvode.atol(1.0e-5)

tv = h.Vector()
vs = h.Vector()
tv.record(h._ref_t)
vs.record(h.soma(0.5)._ref_v)

h.finitialize(v_init)
h.fcurrent()

print('Simulation Start')	
neuron.run(tstop)

ax = plt.subplot()
ax.plot(tv.as_numpy, vs.as_numpy)
plt.savefig('../figs/n13.pdf')  
plt.show()
