# n16.py  Markov model of Na channel
#         Voltage-dependent activation

import numpy as np
import neuron
from neuron import h
import matplotlib.pyplot as plt

nstates = 9

tstop  = 20.0
h.dt   = 0.01

v_init = -100.0
vstart = -100.0
vstep  = 10.0
ntraces = 20
npts   = int(tstop/h.dt)+1
ena = 50.0

c = h.Section()
c.insert('mna')

vc = h.VClamp(0.5, sec=c)
vc.dur[0] = 5.0
vc.dur[1] = 10.0
vc.dur[2] = 5.0
vc.amp[0] = v_init
vc.amp[1] = v_init
vc.amp[2] = v_init

tv = h.Vector()
tv.record(h._ref_t)
gv = h.Vector()
gv.record(c(0.5)._ref_z3_mna)
vv = h.Vector()
vv.record(c(0.5)._ref_v)

traces = []
vtra = []
for i in range(ntraces):
    vc.amp[1] = vstart + vstep * i
    h.finitialize(v_init)
    h.fcurrent()
    neuron.run(tstop)

    traces.append(np.copy(gv.as_numpy()))
    vtra.append(np.copy(vv.as_numpy()))

tt = tv.as_numpy()

f, ax = plt.subplots(2, sharex=True)
for i in range(ntraces):
    ax[0].plot(tt, traces[i])
ax[0].set_ylabel('Open probability')

for i in range(ntraces):
    ax[1].plot(tt, traces[i]*(vtra[i]-ena))
ax[1].set_xlabel('Time (ms)')
ax[1].set_ylabel('Current')

plt.savefig('../figs/n16.pdf')    
plt.show()
