# n18.py  Random network

import neuron
from neuron import h
import numpy as np
import matplotlib.pyplot as plt
import matplotlib

h.load_file ("../utils/ranstream.hoc")
h.load_file('../models/cellModel.hoc')

tstop = 200
h.dt = 0.01
vinit = -65
NCELL = 200  # total number of cells 
C_E = 3      # # of excitatory connections received by each cell

connect_random_low_start_ = 1 # low seed for mcell_ran4_init ( )
cells = []
ranlist = []   # list of the random number sequences
h.mcell_ran4_init(connect_random_low_start_)

# create cells
for i in range(NCELL):        # target (postsynaptic) cell
    cells.append(h.BallStickCell( ))
    ranlist.append(h.RandomStream(i))
    
# make connection
#   no self-connection
#   only one connection from any source
nclist = []
u = np.zeros(NCELL, dtype=int)
for i in range(NCELL): # target cell
    syn = cells[i].synlist.object(0)
    rs = ranlist[i]
    rs.start ( )
    rs.r.discunif(0, NCELL-1) # returns int in range 0..NCELL-1
    u[:] = 0   # u.x[i]==1 means spike source i has already been chosen
    nsyn = 0
    while nsyn < C_E: 
        r = int(rs.repick( ))
        if (r != i) and (u[r] == 0): 
            nc = cells[r].connect2target(syn)
            nclist.append (nc)
            nc.delay = 1
            nc.weight[0] = 0.01 
            u[r] = 1
            nsyn += 1
        #    print("cell %2d -> cell %2d (syn %d)" % (r, i, 0))

print(len(nclist), " connections")

stim = h.NetStim()
stim.number = 1
stim.start = 0
ncstim = h.NetCon (stim, cells[0].synlist[0])
ncstim.delay = 0 
ncstim.weight[0] = 0.01

tvec = h.Vector( )
idvec = h.Vector( )
for i in range(len(cells)):
    nc = cells[i].connect2target(None)
    nc.record (tvec, idvec, i)
    nc.record (tvec, idvec, i)

#for trace
ttvec = h.Vector( )
vvec = h.Vector()
ttvec.record(h._ref_t)
vvec.record(cells[0].soma(0.5)._ref_v)

# Simulation control
h.finitialize(vinit)
neuron.run(tstop )

# Report simulation results
def spikeout ( ):
    print("tvec size = ", int(tvec.size()))
    print("\ntime\t cell\n")
    for i in range(int(tvec.size())):
        print(i, tvec.x[i], idvec.x[i])

# spikeout ( )

spikes = [np.empty(0) for i in range(NCELL)]
for i in range(int(tvec.size())):
    j = int(idvec.x[i])
    spikes[j] = np.append(spikes[j],tvec.x[i])

ax1 = plt.subplot()
ax1.eventplot(spikes, colors=[[1.0, 0, 0]])
plt.ylabel('Cell number')
plt.xlabel('Time (ms)')
plt.savefig('../figs/n18.pdf')
#plt.show(block=False)
#plt.pause(3)
plt.show()

