# n20.py
 
from neuron import h
import neuron
import numpy as np
import matplotlib.pyplot as plt

class InvlFire(object):	
    def __init__(self):
        self.cell = h.Section()
        self.IF = h.IntervalFire(0.5, sec=self.cell)
        self.IF.tau  = 5.0
        self.IF.invl = 10.0

tstop = 200.0
ncells =600
exRatio  = 0.8
inhRatio = 1.0 - exRatio
exCells = int(exRatio*ncells)
inhCells = ncells - exCells
conRateE = 0.005
conRateI = 0.05
synWeightE = 0.01
synWeightI = -0.18

tbin = 2.0
nbin = int((tstop/tbin))+1

print("excitatory cells: ", exCells)
print("inhibitory cells: ", inhCells)

print("estimated excitatory synapses: ", exCells * ncells * conRateE)
print("estimated inhibitory synapses: ", inhCells * ncells * conRateI)


cells = [InvlFire() for i in range(ncells)]
print(len(cells))

"""
# clock-wise connections
nclist = []
for i in range(ncells):
    target = cells[(i+1) % ncells]   # next cell
    nc = h.NetCon(cells[i].IF, target.IF)
    nclist.append(nc)
    nc.delay = 5
    nc.weight[0] = 0.5
"""
# random connections
nclist = []
used = np.zeros(ncells)
for i in range(ncells):
    if(i < exCells):
        maxConnection = int(ncells*conRateE)
        synWeight = synWeightE
    else:
        maxConnection = int(ncells*conRateI)
        synWeight = synWeightI

    ncon = 0
    j = 0  
    used[:] = 0
    trand = np.random.randint(0, ncells, size=ncells)
    while ncon < maxConnection:
        k = trand[j]
        j += 1    
        if(used[k]==0):
#            if(i < excCells):
#                print(i," ==> ", k)
#            else:
#                print(i," --> ", k)
                
            nc = h.NetCon(cells[i].IF, cells[k].IF)
            nclist.append(nc)
            nc.delay = 3
            nc.weight[0] = synWeight
            used[k] = 1
            ncon = ncon+1

# randomize initial state
stim = h.NetStim()
stim.number   = 1
stim.start    = 0 
stim.interval = 1
ncini = []
mr = np.random.uniform(0, 1.0, ncells)
for i in range(ncells):
    ncstim = h.NetCon(stim, cells[i].IF)
    ncstim.delay= 0
    ncstim.weight[0] = mr[i]
    ncini.append(ncstim)

# record for spikes
stvec  = h.Vector( )
idvec = h.Vector( )
for i in range( len(cells) ):
    nc = h.NetCon(cells[i].IF, None)
    nc.record (stvec, idvec, i)

# Simulation control
h.finitialize()
neuron.run(tstop)

#print ("\ntime\t cell\n")
#for i in range(int(tvec.size())):
#    print (i, tvec.x[i], idvec.x[i])
#print("tvec.size=",tvec.size())
hg = np.zeros(nbin, dtype=int)
hge = np.zeros(nbin, dtype=int)
hgi = np.zeros(nbin, dtype=int)
ht = np.linspace(0, tstop, nbin)
for i in range(int(stvec.size())):
    ix = int(stvec.x[i]/tbin)
    hg[ix] = hg[ix] + 1
    if(idvec.x[i]<exCells):
        hge[ix] = hge[ix] + 1
    else:
        hgi[ix] = hgi[ix] + 1
hge = hge.astype(float)/exCells
hgi = hgi.astype(float)/inhCells

f, ax = plt.subplots(3, sharex=True)
ax[0].plot(stvec.as_numpy(), idvec.as_numpy(),'.', markersize=2)
ax[0].set_ylabel('Cell number')
ax[1].plot(ht, hg)
ax[1].set_ylabel('No of spikes')
ax[2].plot(ht, hge)
ax[2].plot(ht, hgi)
ax[2].set_xlabel('Time (ms)')
ax[2].set_ylabel('Probability')

plt.savefig('../figs/n20.pdf')  
plt.show()


"""
spikes = [np.empty(0) for i in range(ncells)]
for i in range(int(stvec.size())):
    j = int(idvec.x[i])
    spikes[j] = np.append(spikes[j],stvec.x[i])
ax1 = plt.subplot()
ax1.eventplot(spikes, colors=[[1.0, 0, 0]])
plt.show()
"""
