
# n21.py collision experiment

from neuron import h
import neuron
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.animation as animation

nsegs = 10000
ulen = 5.0    # unit length in micro-meter
totalLength = ulen * nsegs
npts = nsegs + 1
h.dt = 0.025
dl = 1.0/float(nsegs)

fCollision = False #True

v_init = -65.0
tstop = 100.0

axon = h.Section()
axon.L = totalLength
axon.diam = 2.0
axon.nseg = npts
axon.insert("hh")

cvode = h.CVode()
cvode.active(1)
cvode.atol(1.0e-5)

ic1 = h.IClamp(0.0, sec=axon)
ic1.delay = 1.0 # ms ic.dur = 100.0 # ms
ic1.amp = 0.3  # nA
ic1.dur = 1.0

if fCollision == True:
    ic2 = h.IClamp(1.0, sec=axon)
    ic2.delay = 1.0 # ms ic.dur = 100.0 # ms
    ic2.amp = 0.3  # nA
    ic2.dur = 1.0


yy = []
h.finitialize(v_init)
h.fcurrent()

yv = np.zeros(npts)

while h.t < tstop:
    for i in range(npts):
        yv[i] = axon(dl*i).v
    yy.append(np.copy(yv))
    cvode.fixed_step()

ntraces = len(yy)

fig, ax = plt.subplots(figsize=(10,2))
xv = np.linspace(0.0, totalLength, npts)
yv = np.zeros(npts)
line, = ax.plot(xv,yv)
ax.set_ylim(-100.0,50.0)
nframes = 5
def update(i):
    ydata = yy[nframes*i]
    line.set_ydata(ydata)
    return line,

ani = animation.FuncAnimation(fig, update, frames = int(ntraces/nframes), interval=30)
plt.show()